# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/servicemanagement/v1/servicemanager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import service_pb2 as google_dot_api_dot_service__pb2
from google.api.servicemanagement.v1 import resources_pb2 as google_dot_api_dot_servicemanagement_dot_v1_dot_resources__pb2
from google.longrunning import operations_pb2 as google_dot_longrunning_dot_operations__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/api/servicemanagement/v1/servicemanager.proto',
  package='google.api.servicemanagement.v1',
  syntax='proto3',
  serialized_options=b'\n#com.google.api.servicemanagement.v1B\023ServiceManagerProtoP\001ZPgoogle.golang.org/genproto/googleapis/api/servicemanagement/v1;servicemanagement\242\002\004GASM\252\002!Google.Cloud.ServiceManagement.V1\312\002!Google\\Cloud\\ServiceManagement\\V1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n4google/api/servicemanagement/v1/servicemanager.proto\x12\x1fgoogle.api.servicemanagement.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x18google/api/service.proto\x1a/google/api/servicemanagement/v1/resources.proto\x1a#google/longrunning/operations.proto\x1a\x19google/protobuf/any.proto\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x17google/rpc/status.proto\"n\n\x13ListServicesRequest\x12\x1b\n\x13producer_project_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x05 \x01(\x05\x12\x12\n\npage_token\x18\x06 \x01(\t\x12\x13\n\x0b\x63onsumer_id\x18\x07 \x01(\t\"r\n\x14ListServicesResponse\x12\x41\n\x08services\x18\x01 \x03(\x0b\x32/.google.api.servicemanagement.v1.ManagedService\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\")\n\x11GetServiceRequest\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\"X\n\x14\x43reateServiceRequest\x12@\n\x07service\x18\x01 \x01(\x0b\x32/.google.api.servicemanagement.v1.ManagedService\",\n\x14\x44\x65leteServiceRequest\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\".\n\x16UndeleteServiceRequest\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\"[\n\x17UndeleteServiceResponse\x12@\n\x07service\x18\x01 \x01(\x0b\x32/.google.api.servicemanagement.v1.ManagedService\"\xb8\x01\n\x17GetServiceConfigRequest\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\x11\n\tconfig_id\x18\x02 \x01(\t\x12Q\n\x04view\x18\x03 \x01(\x0e\x32\x43.google.api.servicemanagement.v1.GetServiceConfigRequest.ConfigView\"!\n\nConfigView\x12\t\n\x05\x42\x41SIC\x10\x00\x12\x08\n\x04\x46ULL\x10\x01\"X\n\x19ListServiceConfigsRequest\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\x12\n\npage_token\x18\x02 \x01(\t\x12\x11\n\tpage_size\x18\x03 \x01(\x05\"c\n\x1aListServiceConfigsResponse\x12,\n\x0fservice_configs\x18\x01 \x03(\x0b\x32\x13.google.api.Service\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"_\n\x1a\x43reateServiceConfigRequest\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12+\n\x0eservice_config\x18\x02 \x01(\x0b\x32\x13.google.api.Service\"\x8e\x01\n\x19SubmitConfigSourceRequest\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\x44\n\rconfig_source\x18\x02 \x01(\x0b\x32-.google.api.servicemanagement.v1.ConfigSource\x12\x15\n\rvalidate_only\x18\x03 \x01(\x08\"I\n\x1aSubmitConfigSourceResponse\x12+\n\x0eservice_config\x18\x01 \x01(\x0b\x32\x13.google.api.Service\"n\n\x1b\x43reateServiceRolloutRequest\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\x39\n\x07rollout\x18\x02 \x01(\x0b\x32(.google.api.servicemanagement.v1.Rollout\"i\n\x1aListServiceRolloutsRequest\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\x12\n\npage_token\x18\x02 \x01(\t\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x0e\n\x06\x66ilter\x18\x04 \x01(\t\"r\n\x1bListServiceRolloutsResponse\x12:\n\x08rollouts\x18\x01 \x03(\x0b\x32(.google.api.servicemanagement.v1.Rollout\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"D\n\x18GetServiceRolloutRequest\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\x12\n\nrollout_id\x18\x02 \x01(\t\"A\n\x14\x45nableServiceRequest\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\x13\n\x0b\x63onsumer_id\x18\x02 \x01(\t\"B\n\x15\x44isableServiceRequest\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\x13\n\x0b\x63onsumer_id\x18\x02 \x01(\t\"q\n\x1bGenerateConfigReportRequest\x12(\n\nnew_config\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12(\n\nold_config\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\"\xc9\x01\n\x1cGenerateConfigReportResponse\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x45\n\x0e\x63hange_reports\x18\x03 \x03(\x0b\x32-.google.api.servicemanagement.v1.ChangeReport\x12@\n\x0b\x64iagnostics\x18\x04 \x03(\x0b\x32+.google.api.servicemanagement.v1.Diagnostic2\xd4\x13\n\x0eServiceManager\x12\x91\x01\n\x0cListServices\x12\x34.google.api.servicemanagement.v1.ListServicesRequest\x1a\x35.google.api.servicemanagement.v1.ListServicesResponse\"\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/v1/services\x12\x96\x01\n\nGetService\x12\x32.google.api.servicemanagement.v1.GetServiceRequest\x1a/.google.api.servicemanagement.v1.ManagedService\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v1/services/{service_name}\x12\x84\x01\n\rCreateService\x12\x35.google.api.servicemanagement.v1.CreateServiceRequest\x1a\x1d.google.longrunning.Operation\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x0c/v1/services:\x07service\x12\x8a\x01\n\rDeleteService\x12\x35.google.api.servicemanagement.v1.DeleteServiceRequest\x1a\x1d.google.longrunning.Operation\"#\x82\xd3\xe4\x93\x02\x1d*\x1b/v1/services/{service_name}\x12\x97\x01\n\x0fUndeleteService\x12\x37.google.api.servicemanagement.v1.UndeleteServiceRequest\x1a\x1d.google.longrunning.Operation\",\x82\xd3\xe4\x93\x02&\"$/v1/services/{service_name}:undelete\x12\xba\x01\n\x12ListServiceConfigs\x12:.google.api.servicemanagement.v1.ListServiceConfigsRequest\x1a;.google.api.servicemanagement.v1.ListServiceConfigsResponse\"+\x82\xd3\xe4\x93\x02%\x12#/v1/services/{service_name}/configs\x12\xc0\x01\n\x10GetServiceConfig\x12\x38.google.api.servicemanagement.v1.GetServiceConfigRequest\x1a\x13.google.api.Service\"]\x82\xd3\xe4\x93\x02W\x12//v1/services/{service_name}/configs/{config_id}Z$\x12\"/v1/services/{service_name}/config\x12\xa4\x01\n\x13\x43reateServiceConfig\x12;.google.api.servicemanagement.v1.CreateServiceConfigRequest\x1a\x13.google.api.Service\";\x82\xd3\xe4\x93\x02\x35\"#/v1/services/{service_name}/configs:\x0eservice_config\x12\xa6\x01\n\x12SubmitConfigSource\x12:.google.api.servicemanagement.v1.SubmitConfigSourceRequest\x1a\x1d.google.longrunning.Operation\"5\x82\xd3\xe4\x93\x02/\"*/v1/services/{service_name}/configs:submit:\x01*\x12\xbe\x01\n\x13ListServiceRollouts\x12;.google.api.servicemanagement.v1.ListServiceRolloutsRequest\x1a<.google.api.servicemanagement.v1.ListServiceRolloutsResponse\",\x82\xd3\xe4\x93\x02&\x12$/v1/services/{service_name}/rollouts\x12\xb3\x01\n\x11GetServiceRollout\x12\x39.google.api.servicemanagement.v1.GetServiceRolloutRequest\x1a(.google.api.servicemanagement.v1.Rollout\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/v1/services/{service_name}/rollouts/{rollout_id}\x12\xaa\x01\n\x14\x43reateServiceRollout\x12<.google.api.servicemanagement.v1.CreateServiceRolloutRequest\x1a\x1d.google.longrunning.Operation\"5\x82\xd3\xe4\x93\x02/\"$/v1/services/{service_name}/rollouts:\x07rollout\x12\xc1\x01\n\x14GenerateConfigReport\x12<.google.api.servicemanagement.v1.GenerateConfigReportRequest\x1a=.google.api.servicemanagement.v1.GenerateConfigReportResponse\",\x82\xd3\xe4\x93\x02&\"!/v1/services:generateConfigReport:\x01*\x12\x94\x01\n\rEnableService\x12\x35.google.api.servicemanagement.v1.EnableServiceRequest\x1a\x1d.google.longrunning.Operation\"-\x82\xd3\xe4\x93\x02\'\"\"/v1/services/{service_name}:enable:\x01*\x12\x97\x01\n\x0e\x44isableService\x12\x36.google.api.servicemanagement.v1.DisableServiceRequest\x1a\x1d.google.longrunning.Operation\".\x82\xd3\xe4\x93\x02(\"#/v1/services/{service_name}:disable:\x01*B\xdd\x01\n#com.google.api.servicemanagement.v1B\x13ServiceManagerProtoP\x01ZPgoogle.golang.org/genproto/googleapis/api/servicemanagement/v1;servicemanagement\xa2\x02\x04GASM\xaa\x02!Google.Cloud.ServiceManagement.V1\xca\x02!Google\\Cloud\\ServiceManagement\\V1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_api_dot_service__pb2.DESCRIPTOR,google_dot_api_dot_servicemanagement_dot_v1_dot_resources__pb2.DESCRIPTOR,google_dot_longrunning_dot_operations__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,google_dot_rpc_dot_status__pb2.DESCRIPTOR,])



_GETSERVICECONFIGREQUEST_CONFIGVIEW = _descriptor.EnumDescriptor(
  name='ConfigView',
  full_name='google.api.servicemanagement.v1.GetServiceConfigRequest.ConfigView',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BASIC', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FULL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1047,
  serialized_end=1080,
)
_sym_db.RegisterEnumDescriptor(_GETSERVICECONFIGREQUEST_CONFIGVIEW)


_LISTSERVICESREQUEST = _descriptor.Descriptor(
  name='ListServicesRequest',
  full_name='google.api.servicemanagement.v1.ListServicesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='producer_project_id', full_name='google.api.servicemanagement.v1.ListServicesRequest.producer_project_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='google.api.servicemanagement.v1.ListServicesRequest.page_size', index=1,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='google.api.servicemanagement.v1.ListServicesRequest.page_token', index=2,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='consumer_id', full_name='google.api.servicemanagement.v1.ListServicesRequest.consumer_id', index=3,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=347,
  serialized_end=457,
)


_LISTSERVICESRESPONSE = _descriptor.Descriptor(
  name='ListServicesResponse',
  full_name='google.api.servicemanagement.v1.ListServicesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='services', full_name='google.api.servicemanagement.v1.ListServicesResponse.services', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='google.api.servicemanagement.v1.ListServicesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=459,
  serialized_end=573,
)


_GETSERVICEREQUEST = _descriptor.Descriptor(
  name='GetServiceRequest',
  full_name='google.api.servicemanagement.v1.GetServiceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_name', full_name='google.api.servicemanagement.v1.GetServiceRequest.service_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=575,
  serialized_end=616,
)


_CREATESERVICEREQUEST = _descriptor.Descriptor(
  name='CreateServiceRequest',
  full_name='google.api.servicemanagement.v1.CreateServiceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service', full_name='google.api.servicemanagement.v1.CreateServiceRequest.service', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=618,
  serialized_end=706,
)


_DELETESERVICEREQUEST = _descriptor.Descriptor(
  name='DeleteServiceRequest',
  full_name='google.api.servicemanagement.v1.DeleteServiceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_name', full_name='google.api.servicemanagement.v1.DeleteServiceRequest.service_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=708,
  serialized_end=752,
)


_UNDELETESERVICEREQUEST = _descriptor.Descriptor(
  name='UndeleteServiceRequest',
  full_name='google.api.servicemanagement.v1.UndeleteServiceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_name', full_name='google.api.servicemanagement.v1.UndeleteServiceRequest.service_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=754,
  serialized_end=800,
)


_UNDELETESERVICERESPONSE = _descriptor.Descriptor(
  name='UndeleteServiceResponse',
  full_name='google.api.servicemanagement.v1.UndeleteServiceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service', full_name='google.api.servicemanagement.v1.UndeleteServiceResponse.service', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=802,
  serialized_end=893,
)


_GETSERVICECONFIGREQUEST = _descriptor.Descriptor(
  name='GetServiceConfigRequest',
  full_name='google.api.servicemanagement.v1.GetServiceConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_name', full_name='google.api.servicemanagement.v1.GetServiceConfigRequest.service_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config_id', full_name='google.api.servicemanagement.v1.GetServiceConfigRequest.config_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='view', full_name='google.api.servicemanagement.v1.GetServiceConfigRequest.view', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GETSERVICECONFIGREQUEST_CONFIGVIEW,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=896,
  serialized_end=1080,
)


_LISTSERVICECONFIGSREQUEST = _descriptor.Descriptor(
  name='ListServiceConfigsRequest',
  full_name='google.api.servicemanagement.v1.ListServiceConfigsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_name', full_name='google.api.servicemanagement.v1.ListServiceConfigsRequest.service_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='google.api.servicemanagement.v1.ListServiceConfigsRequest.page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='google.api.servicemanagement.v1.ListServiceConfigsRequest.page_size', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1082,
  serialized_end=1170,
)


_LISTSERVICECONFIGSRESPONSE = _descriptor.Descriptor(
  name='ListServiceConfigsResponse',
  full_name='google.api.servicemanagement.v1.ListServiceConfigsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_configs', full_name='google.api.servicemanagement.v1.ListServiceConfigsResponse.service_configs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='google.api.servicemanagement.v1.ListServiceConfigsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1172,
  serialized_end=1271,
)


_CREATESERVICECONFIGREQUEST = _descriptor.Descriptor(
  name='CreateServiceConfigRequest',
  full_name='google.api.servicemanagement.v1.CreateServiceConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_name', full_name='google.api.servicemanagement.v1.CreateServiceConfigRequest.service_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_config', full_name='google.api.servicemanagement.v1.CreateServiceConfigRequest.service_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1273,
  serialized_end=1368,
)


_SUBMITCONFIGSOURCEREQUEST = _descriptor.Descriptor(
  name='SubmitConfigSourceRequest',
  full_name='google.api.servicemanagement.v1.SubmitConfigSourceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_name', full_name='google.api.servicemanagement.v1.SubmitConfigSourceRequest.service_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config_source', full_name='google.api.servicemanagement.v1.SubmitConfigSourceRequest.config_source', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validate_only', full_name='google.api.servicemanagement.v1.SubmitConfigSourceRequest.validate_only', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1371,
  serialized_end=1513,
)


_SUBMITCONFIGSOURCERESPONSE = _descriptor.Descriptor(
  name='SubmitConfigSourceResponse',
  full_name='google.api.servicemanagement.v1.SubmitConfigSourceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_config', full_name='google.api.servicemanagement.v1.SubmitConfigSourceResponse.service_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1515,
  serialized_end=1588,
)


_CREATESERVICEROLLOUTREQUEST = _descriptor.Descriptor(
  name='CreateServiceRolloutRequest',
  full_name='google.api.servicemanagement.v1.CreateServiceRolloutRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_name', full_name='google.api.servicemanagement.v1.CreateServiceRolloutRequest.service_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rollout', full_name='google.api.servicemanagement.v1.CreateServiceRolloutRequest.rollout', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1590,
  serialized_end=1700,
)


_LISTSERVICEROLLOUTSREQUEST = _descriptor.Descriptor(
  name='ListServiceRolloutsRequest',
  full_name='google.api.servicemanagement.v1.ListServiceRolloutsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_name', full_name='google.api.servicemanagement.v1.ListServiceRolloutsRequest.service_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='google.api.servicemanagement.v1.ListServiceRolloutsRequest.page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='google.api.servicemanagement.v1.ListServiceRolloutsRequest.page_size', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='google.api.servicemanagement.v1.ListServiceRolloutsRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1702,
  serialized_end=1807,
)


_LISTSERVICEROLLOUTSRESPONSE = _descriptor.Descriptor(
  name='ListServiceRolloutsResponse',
  full_name='google.api.servicemanagement.v1.ListServiceRolloutsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rollouts', full_name='google.api.servicemanagement.v1.ListServiceRolloutsResponse.rollouts', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='google.api.servicemanagement.v1.ListServiceRolloutsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1809,
  serialized_end=1923,
)


_GETSERVICEROLLOUTREQUEST = _descriptor.Descriptor(
  name='GetServiceRolloutRequest',
  full_name='google.api.servicemanagement.v1.GetServiceRolloutRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_name', full_name='google.api.servicemanagement.v1.GetServiceRolloutRequest.service_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rollout_id', full_name='google.api.servicemanagement.v1.GetServiceRolloutRequest.rollout_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1925,
  serialized_end=1993,
)


_ENABLESERVICEREQUEST = _descriptor.Descriptor(
  name='EnableServiceRequest',
  full_name='google.api.servicemanagement.v1.EnableServiceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_name', full_name='google.api.servicemanagement.v1.EnableServiceRequest.service_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='consumer_id', full_name='google.api.servicemanagement.v1.EnableServiceRequest.consumer_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1995,
  serialized_end=2060,
)


_DISABLESERVICEREQUEST = _descriptor.Descriptor(
  name='DisableServiceRequest',
  full_name='google.api.servicemanagement.v1.DisableServiceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_name', full_name='google.api.servicemanagement.v1.DisableServiceRequest.service_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='consumer_id', full_name='google.api.servicemanagement.v1.DisableServiceRequest.consumer_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2062,
  serialized_end=2128,
)


_GENERATECONFIGREPORTREQUEST = _descriptor.Descriptor(
  name='GenerateConfigReportRequest',
  full_name='google.api.servicemanagement.v1.GenerateConfigReportRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='new_config', full_name='google.api.servicemanagement.v1.GenerateConfigReportRequest.new_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='old_config', full_name='google.api.servicemanagement.v1.GenerateConfigReportRequest.old_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2130,
  serialized_end=2243,
)


_GENERATECONFIGREPORTRESPONSE = _descriptor.Descriptor(
  name='GenerateConfigReportResponse',
  full_name='google.api.servicemanagement.v1.GenerateConfigReportResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_name', full_name='google.api.servicemanagement.v1.GenerateConfigReportResponse.service_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='google.api.servicemanagement.v1.GenerateConfigReportResponse.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='change_reports', full_name='google.api.servicemanagement.v1.GenerateConfigReportResponse.change_reports', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='diagnostics', full_name='google.api.servicemanagement.v1.GenerateConfigReportResponse.diagnostics', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2246,
  serialized_end=2447,
)

_LISTSERVICESRESPONSE.fields_by_name['services'].message_type = google_dot_api_dot_servicemanagement_dot_v1_dot_resources__pb2._MANAGEDSERVICE
_CREATESERVICEREQUEST.fields_by_name['service'].message_type = google_dot_api_dot_servicemanagement_dot_v1_dot_resources__pb2._MANAGEDSERVICE
_UNDELETESERVICERESPONSE.fields_by_name['service'].message_type = google_dot_api_dot_servicemanagement_dot_v1_dot_resources__pb2._MANAGEDSERVICE
_GETSERVICECONFIGREQUEST.fields_by_name['view'].enum_type = _GETSERVICECONFIGREQUEST_CONFIGVIEW
_GETSERVICECONFIGREQUEST_CONFIGVIEW.containing_type = _GETSERVICECONFIGREQUEST
_LISTSERVICECONFIGSRESPONSE.fields_by_name['service_configs'].message_type = google_dot_api_dot_service__pb2._SERVICE
_CREATESERVICECONFIGREQUEST.fields_by_name['service_config'].message_type = google_dot_api_dot_service__pb2._SERVICE
_SUBMITCONFIGSOURCEREQUEST.fields_by_name['config_source'].message_type = google_dot_api_dot_servicemanagement_dot_v1_dot_resources__pb2._CONFIGSOURCE
_SUBMITCONFIGSOURCERESPONSE.fields_by_name['service_config'].message_type = google_dot_api_dot_service__pb2._SERVICE
_CREATESERVICEROLLOUTREQUEST.fields_by_name['rollout'].message_type = google_dot_api_dot_servicemanagement_dot_v1_dot_resources__pb2._ROLLOUT
_LISTSERVICEROLLOUTSRESPONSE.fields_by_name['rollouts'].message_type = google_dot_api_dot_servicemanagement_dot_v1_dot_resources__pb2._ROLLOUT
_GENERATECONFIGREPORTREQUEST.fields_by_name['new_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_GENERATECONFIGREPORTREQUEST.fields_by_name['old_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_GENERATECONFIGREPORTRESPONSE.fields_by_name['change_reports'].message_type = google_dot_api_dot_servicemanagement_dot_v1_dot_resources__pb2._CHANGEREPORT
_GENERATECONFIGREPORTRESPONSE.fields_by_name['diagnostics'].message_type = google_dot_api_dot_servicemanagement_dot_v1_dot_resources__pb2._DIAGNOSTIC
DESCRIPTOR.message_types_by_name['ListServicesRequest'] = _LISTSERVICESREQUEST
DESCRIPTOR.message_types_by_name['ListServicesResponse'] = _LISTSERVICESRESPONSE
DESCRIPTOR.message_types_by_name['GetServiceRequest'] = _GETSERVICEREQUEST
DESCRIPTOR.message_types_by_name['CreateServiceRequest'] = _CREATESERVICEREQUEST
DESCRIPTOR.message_types_by_name['DeleteServiceRequest'] = _DELETESERVICEREQUEST
DESCRIPTOR.message_types_by_name['UndeleteServiceRequest'] = _UNDELETESERVICEREQUEST
DESCRIPTOR.message_types_by_name['UndeleteServiceResponse'] = _UNDELETESERVICERESPONSE
DESCRIPTOR.message_types_by_name['GetServiceConfigRequest'] = _GETSERVICECONFIGREQUEST
DESCRIPTOR.message_types_by_name['ListServiceConfigsRequest'] = _LISTSERVICECONFIGSREQUEST
DESCRIPTOR.message_types_by_name['ListServiceConfigsResponse'] = _LISTSERVICECONFIGSRESPONSE
DESCRIPTOR.message_types_by_name['CreateServiceConfigRequest'] = _CREATESERVICECONFIGREQUEST
DESCRIPTOR.message_types_by_name['SubmitConfigSourceRequest'] = _SUBMITCONFIGSOURCEREQUEST
DESCRIPTOR.message_types_by_name['SubmitConfigSourceResponse'] = _SUBMITCONFIGSOURCERESPONSE
DESCRIPTOR.message_types_by_name['CreateServiceRolloutRequest'] = _CREATESERVICEROLLOUTREQUEST
DESCRIPTOR.message_types_by_name['ListServiceRolloutsRequest'] = _LISTSERVICEROLLOUTSREQUEST
DESCRIPTOR.message_types_by_name['ListServiceRolloutsResponse'] = _LISTSERVICEROLLOUTSRESPONSE
DESCRIPTOR.message_types_by_name['GetServiceRolloutRequest'] = _GETSERVICEROLLOUTREQUEST
DESCRIPTOR.message_types_by_name['EnableServiceRequest'] = _ENABLESERVICEREQUEST
DESCRIPTOR.message_types_by_name['DisableServiceRequest'] = _DISABLESERVICEREQUEST
DESCRIPTOR.message_types_by_name['GenerateConfigReportRequest'] = _GENERATECONFIGREPORTREQUEST
DESCRIPTOR.message_types_by_name['GenerateConfigReportResponse'] = _GENERATECONFIGREPORTRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListServicesRequest = _reflection.GeneratedProtocolMessageType('ListServicesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSERVICESREQUEST,
  '__module__' : 'google.api.servicemanagement.v1.servicemanager_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicemanagement.v1.ListServicesRequest)
  })
_sym_db.RegisterMessage(ListServicesRequest)

ListServicesResponse = _reflection.GeneratedProtocolMessageType('ListServicesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSERVICESRESPONSE,
  '__module__' : 'google.api.servicemanagement.v1.servicemanager_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicemanagement.v1.ListServicesResponse)
  })
_sym_db.RegisterMessage(ListServicesResponse)

GetServiceRequest = _reflection.GeneratedProtocolMessageType('GetServiceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVICEREQUEST,
  '__module__' : 'google.api.servicemanagement.v1.servicemanager_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicemanagement.v1.GetServiceRequest)
  })
_sym_db.RegisterMessage(GetServiceRequest)

CreateServiceRequest = _reflection.GeneratedProtocolMessageType('CreateServiceRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESERVICEREQUEST,
  '__module__' : 'google.api.servicemanagement.v1.servicemanager_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicemanagement.v1.CreateServiceRequest)
  })
_sym_db.RegisterMessage(CreateServiceRequest)

DeleteServiceRequest = _reflection.GeneratedProtocolMessageType('DeleteServiceRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETESERVICEREQUEST,
  '__module__' : 'google.api.servicemanagement.v1.servicemanager_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicemanagement.v1.DeleteServiceRequest)
  })
_sym_db.RegisterMessage(DeleteServiceRequest)

UndeleteServiceRequest = _reflection.GeneratedProtocolMessageType('UndeleteServiceRequest', (_message.Message,), {
  'DESCRIPTOR' : _UNDELETESERVICEREQUEST,
  '__module__' : 'google.api.servicemanagement.v1.servicemanager_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicemanagement.v1.UndeleteServiceRequest)
  })
_sym_db.RegisterMessage(UndeleteServiceRequest)

UndeleteServiceResponse = _reflection.GeneratedProtocolMessageType('UndeleteServiceResponse', (_message.Message,), {
  'DESCRIPTOR' : _UNDELETESERVICERESPONSE,
  '__module__' : 'google.api.servicemanagement.v1.servicemanager_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicemanagement.v1.UndeleteServiceResponse)
  })
_sym_db.RegisterMessage(UndeleteServiceResponse)

GetServiceConfigRequest = _reflection.GeneratedProtocolMessageType('GetServiceConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVICECONFIGREQUEST,
  '__module__' : 'google.api.servicemanagement.v1.servicemanager_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicemanagement.v1.GetServiceConfigRequest)
  })
_sym_db.RegisterMessage(GetServiceConfigRequest)

ListServiceConfigsRequest = _reflection.GeneratedProtocolMessageType('ListServiceConfigsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSERVICECONFIGSREQUEST,
  '__module__' : 'google.api.servicemanagement.v1.servicemanager_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicemanagement.v1.ListServiceConfigsRequest)
  })
_sym_db.RegisterMessage(ListServiceConfigsRequest)

ListServiceConfigsResponse = _reflection.GeneratedProtocolMessageType('ListServiceConfigsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSERVICECONFIGSRESPONSE,
  '__module__' : 'google.api.servicemanagement.v1.servicemanager_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicemanagement.v1.ListServiceConfigsResponse)
  })
_sym_db.RegisterMessage(ListServiceConfigsResponse)

CreateServiceConfigRequest = _reflection.GeneratedProtocolMessageType('CreateServiceConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESERVICECONFIGREQUEST,
  '__module__' : 'google.api.servicemanagement.v1.servicemanager_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicemanagement.v1.CreateServiceConfigRequest)
  })
_sym_db.RegisterMessage(CreateServiceConfigRequest)

SubmitConfigSourceRequest = _reflection.GeneratedProtocolMessageType('SubmitConfigSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUBMITCONFIGSOURCEREQUEST,
  '__module__' : 'google.api.servicemanagement.v1.servicemanager_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicemanagement.v1.SubmitConfigSourceRequest)
  })
_sym_db.RegisterMessage(SubmitConfigSourceRequest)

SubmitConfigSourceResponse = _reflection.GeneratedProtocolMessageType('SubmitConfigSourceResponse', (_message.Message,), {
  'DESCRIPTOR' : _SUBMITCONFIGSOURCERESPONSE,
  '__module__' : 'google.api.servicemanagement.v1.servicemanager_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicemanagement.v1.SubmitConfigSourceResponse)
  })
_sym_db.RegisterMessage(SubmitConfigSourceResponse)

CreateServiceRolloutRequest = _reflection.GeneratedProtocolMessageType('CreateServiceRolloutRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESERVICEROLLOUTREQUEST,
  '__module__' : 'google.api.servicemanagement.v1.servicemanager_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicemanagement.v1.CreateServiceRolloutRequest)
  })
_sym_db.RegisterMessage(CreateServiceRolloutRequest)

ListServiceRolloutsRequest = _reflection.GeneratedProtocolMessageType('ListServiceRolloutsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSERVICEROLLOUTSREQUEST,
  '__module__' : 'google.api.servicemanagement.v1.servicemanager_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicemanagement.v1.ListServiceRolloutsRequest)
  })
_sym_db.RegisterMessage(ListServiceRolloutsRequest)

ListServiceRolloutsResponse = _reflection.GeneratedProtocolMessageType('ListServiceRolloutsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSERVICEROLLOUTSRESPONSE,
  '__module__' : 'google.api.servicemanagement.v1.servicemanager_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicemanagement.v1.ListServiceRolloutsResponse)
  })
_sym_db.RegisterMessage(ListServiceRolloutsResponse)

GetServiceRolloutRequest = _reflection.GeneratedProtocolMessageType('GetServiceRolloutRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVICEROLLOUTREQUEST,
  '__module__' : 'google.api.servicemanagement.v1.servicemanager_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicemanagement.v1.GetServiceRolloutRequest)
  })
_sym_db.RegisterMessage(GetServiceRolloutRequest)

EnableServiceRequest = _reflection.GeneratedProtocolMessageType('EnableServiceRequest', (_message.Message,), {
  'DESCRIPTOR' : _ENABLESERVICEREQUEST,
  '__module__' : 'google.api.servicemanagement.v1.servicemanager_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicemanagement.v1.EnableServiceRequest)
  })
_sym_db.RegisterMessage(EnableServiceRequest)

DisableServiceRequest = _reflection.GeneratedProtocolMessageType('DisableServiceRequest', (_message.Message,), {
  'DESCRIPTOR' : _DISABLESERVICEREQUEST,
  '__module__' : 'google.api.servicemanagement.v1.servicemanager_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicemanagement.v1.DisableServiceRequest)
  })
_sym_db.RegisterMessage(DisableServiceRequest)

GenerateConfigReportRequest = _reflection.GeneratedProtocolMessageType('GenerateConfigReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _GENERATECONFIGREPORTREQUEST,
  '__module__' : 'google.api.servicemanagement.v1.servicemanager_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicemanagement.v1.GenerateConfigReportRequest)
  })
_sym_db.RegisterMessage(GenerateConfigReportRequest)

GenerateConfigReportResponse = _reflection.GeneratedProtocolMessageType('GenerateConfigReportResponse', (_message.Message,), {
  'DESCRIPTOR' : _GENERATECONFIGREPORTRESPONSE,
  '__module__' : 'google.api.servicemanagement.v1.servicemanager_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicemanagement.v1.GenerateConfigReportResponse)
  })
_sym_db.RegisterMessage(GenerateConfigReportResponse)


DESCRIPTOR._options = None

_SERVICEMANAGER = _descriptor.ServiceDescriptor(
  name='ServiceManager',
  full_name='google.api.servicemanagement.v1.ServiceManager',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2450,
  serialized_end=4966,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListServices',
    full_name='google.api.servicemanagement.v1.ServiceManager.ListServices',
    index=0,
    containing_service=None,
    input_type=_LISTSERVICESREQUEST,
    output_type=_LISTSERVICESRESPONSE,
    serialized_options=b'\202\323\344\223\002\016\022\014/v1/services',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetService',
    full_name='google.api.servicemanagement.v1.ServiceManager.GetService',
    index=1,
    containing_service=None,
    input_type=_GETSERVICEREQUEST,
    output_type=google_dot_api_dot_servicemanagement_dot_v1_dot_resources__pb2._MANAGEDSERVICE,
    serialized_options=b'\202\323\344\223\002\035\022\033/v1/services/{service_name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateService',
    full_name='google.api.servicemanagement.v1.ServiceManager.CreateService',
    index=2,
    containing_service=None,
    input_type=_CREATESERVICEREQUEST,
    output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\027\"\014/v1/services:\007service',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteService',
    full_name='google.api.servicemanagement.v1.ServiceManager.DeleteService',
    index=3,
    containing_service=None,
    input_type=_DELETESERVICEREQUEST,
    output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\035*\033/v1/services/{service_name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UndeleteService',
    full_name='google.api.servicemanagement.v1.ServiceManager.UndeleteService',
    index=4,
    containing_service=None,
    input_type=_UNDELETESERVICEREQUEST,
    output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002&\"$/v1/services/{service_name}:undelete',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListServiceConfigs',
    full_name='google.api.servicemanagement.v1.ServiceManager.ListServiceConfigs',
    index=5,
    containing_service=None,
    input_type=_LISTSERVICECONFIGSREQUEST,
    output_type=_LISTSERVICECONFIGSRESPONSE,
    serialized_options=b'\202\323\344\223\002%\022#/v1/services/{service_name}/configs',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetServiceConfig',
    full_name='google.api.servicemanagement.v1.ServiceManager.GetServiceConfig',
    index=6,
    containing_service=None,
    input_type=_GETSERVICECONFIGREQUEST,
    output_type=google_dot_api_dot_service__pb2._SERVICE,
    serialized_options=b'\202\323\344\223\002W\022//v1/services/{service_name}/configs/{config_id}Z$\022\"/v1/services/{service_name}/config',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateServiceConfig',
    full_name='google.api.servicemanagement.v1.ServiceManager.CreateServiceConfig',
    index=7,
    containing_service=None,
    input_type=_CREATESERVICECONFIGREQUEST,
    output_type=google_dot_api_dot_service__pb2._SERVICE,
    serialized_options=b'\202\323\344\223\0025\"#/v1/services/{service_name}/configs:\016service_config',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SubmitConfigSource',
    full_name='google.api.servicemanagement.v1.ServiceManager.SubmitConfigSource',
    index=8,
    containing_service=None,
    input_type=_SUBMITCONFIGSOURCEREQUEST,
    output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002/\"*/v1/services/{service_name}/configs:submit:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListServiceRollouts',
    full_name='google.api.servicemanagement.v1.ServiceManager.ListServiceRollouts',
    index=9,
    containing_service=None,
    input_type=_LISTSERVICEROLLOUTSREQUEST,
    output_type=_LISTSERVICEROLLOUTSRESPONSE,
    serialized_options=b'\202\323\344\223\002&\022$/v1/services/{service_name}/rollouts',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetServiceRollout',
    full_name='google.api.servicemanagement.v1.ServiceManager.GetServiceRollout',
    index=10,
    containing_service=None,
    input_type=_GETSERVICEROLLOUTREQUEST,
    output_type=google_dot_api_dot_servicemanagement_dot_v1_dot_resources__pb2._ROLLOUT,
    serialized_options=b'\202\323\344\223\0023\0221/v1/services/{service_name}/rollouts/{rollout_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateServiceRollout',
    full_name='google.api.servicemanagement.v1.ServiceManager.CreateServiceRollout',
    index=11,
    containing_service=None,
    input_type=_CREATESERVICEROLLOUTREQUEST,
    output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002/\"$/v1/services/{service_name}/rollouts:\007rollout',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GenerateConfigReport',
    full_name='google.api.servicemanagement.v1.ServiceManager.GenerateConfigReport',
    index=12,
    containing_service=None,
    input_type=_GENERATECONFIGREPORTREQUEST,
    output_type=_GENERATECONFIGREPORTRESPONSE,
    serialized_options=b'\202\323\344\223\002&\"!/v1/services:generateConfigReport:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EnableService',
    full_name='google.api.servicemanagement.v1.ServiceManager.EnableService',
    index=13,
    containing_service=None,
    input_type=_ENABLESERVICEREQUEST,
    output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\'\"\"/v1/services/{service_name}:enable:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DisableService',
    full_name='google.api.servicemanagement.v1.ServiceManager.DisableService',
    index=14,
    containing_service=None,
    input_type=_DISABLESERVICEREQUEST,
    output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002(\"#/v1/services/{service_name}:disable:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SERVICEMANAGER)

DESCRIPTOR.services_by_name['ServiceManager'] = _SERVICEMANAGER

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/event_reporting/v2alpha/event_reporting_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/service/event_reporting/v2alpha/event_reporting_service.proto',
  package='envoy.service.event_reporting.v2alpha',
  syntax='proto3',
  serialized_options=b'\n3io.envoyproxy.envoy.service.event_reporting.v2alphaB\032EventReportingServiceProtoP\001\210\001\001\362\230\376\217\005\"\022 envoy.service.event_reporting.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nCenvoy/service/event_reporting/v2alpha/event_reporting_service.proto\x12%envoy.service.event_reporting.v2alpha\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a\x19google/protobuf/any.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xdf\x01\n\x13StreamEventsRequest\x12Y\n\nidentifier\x18\x01 \x01(\x0b\x32\x45.envoy.service.event_reporting.v2alpha.StreamEventsRequest.Identifier\x12.\n\x06\x65vents\x18\x02 \x03(\x0b\x32\x14.google.protobuf.AnyB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a=\n\nIdentifier\x12/\n\x04node\x18\x01 \x01(\x0b\x32\x17.envoy.api.v2.core.NodeB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\x16\n\x14StreamEventsResponse2\xa7\x01\n\x15\x45ventReportingService\x12\x8d\x01\n\x0cStreamEvents\x12:.envoy.service.event_reporting.v2alpha.StreamEventsRequest\x1a;.envoy.service.event_reporting.v2alpha.StreamEventsResponse\"\x00(\x01\x30\x01\x42\x86\x01\n3io.envoyproxy.envoy.service.event_reporting.v2alphaB\x1a\x45ventReportingServiceProtoP\x01\x88\x01\x01\xf2\x98\xfe\x8f\x05\"\x12 envoy.service.event_reporting.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_base__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_STREAMEVENTSREQUEST_IDENTIFIER = _descriptor.Descriptor(
  name='Identifier',
  full_name='envoy.service.event_reporting.v2alpha.StreamEventsRequest.Identifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node', full_name='envoy.service.event_reporting.v2alpha.StreamEventsRequest.Identifier.node', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=418,
  serialized_end=479,
)

_STREAMEVENTSREQUEST = _descriptor.Descriptor(
  name='StreamEventsRequest',
  full_name='envoy.service.event_reporting.v2alpha.StreamEventsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='envoy.service.event_reporting.v2alpha.StreamEventsRequest.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='events', full_name='envoy.service.event_reporting.v2alpha.StreamEventsRequest.events', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STREAMEVENTSREQUEST_IDENTIFIER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=256,
  serialized_end=479,
)


_STREAMEVENTSRESPONSE = _descriptor.Descriptor(
  name='StreamEventsResponse',
  full_name='envoy.service.event_reporting.v2alpha.StreamEventsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=481,
  serialized_end=503,
)

_STREAMEVENTSREQUEST_IDENTIFIER.fields_by_name['node'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._NODE
_STREAMEVENTSREQUEST_IDENTIFIER.containing_type = _STREAMEVENTSREQUEST
_STREAMEVENTSREQUEST.fields_by_name['identifier'].message_type = _STREAMEVENTSREQUEST_IDENTIFIER
_STREAMEVENTSREQUEST.fields_by_name['events'].message_type = google_dot_protobuf_dot_any__pb2._ANY
DESCRIPTOR.message_types_by_name['StreamEventsRequest'] = _STREAMEVENTSREQUEST
DESCRIPTOR.message_types_by_name['StreamEventsResponse'] = _STREAMEVENTSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StreamEventsRequest = _reflection.GeneratedProtocolMessageType('StreamEventsRequest', (_message.Message,), {

  'Identifier' : _reflection.GeneratedProtocolMessageType('Identifier', (_message.Message,), {
    'DESCRIPTOR' : _STREAMEVENTSREQUEST_IDENTIFIER,
    '__module__' : 'envoy.service.event_reporting.v2alpha.event_reporting_service_pb2'
    # @@protoc_insertion_point(class_scope:envoy.service.event_reporting.v2alpha.StreamEventsRequest.Identifier)
    })
  ,
  'DESCRIPTOR' : _STREAMEVENTSREQUEST,
  '__module__' : 'envoy.service.event_reporting.v2alpha.event_reporting_service_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.event_reporting.v2alpha.StreamEventsRequest)
  })
_sym_db.RegisterMessage(StreamEventsRequest)
_sym_db.RegisterMessage(StreamEventsRequest.Identifier)

StreamEventsResponse = _reflection.GeneratedProtocolMessageType('StreamEventsResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMEVENTSRESPONSE,
  '__module__' : 'envoy.service.event_reporting.v2alpha.event_reporting_service_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.event_reporting.v2alpha.StreamEventsResponse)
  })
_sym_db.RegisterMessage(StreamEventsResponse)


DESCRIPTOR._options = None
_STREAMEVENTSREQUEST_IDENTIFIER.fields_by_name['node']._options = None
_STREAMEVENTSREQUEST.fields_by_name['events']._options = None

_EVENTREPORTINGSERVICE = _descriptor.ServiceDescriptor(
  name='EventReportingService',
  full_name='envoy.service.event_reporting.v2alpha.EventReportingService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=506,
  serialized_end=673,
  methods=[
  _descriptor.MethodDescriptor(
    name='StreamEvents',
    full_name='envoy.service.event_reporting.v2alpha.EventReportingService.StreamEvents',
    index=0,
    containing_service=None,
    input_type=_STREAMEVENTSREQUEST,
    output_type=_STREAMEVENTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_EVENTREPORTINGSERVICE)

DESCRIPTOR.services_by_name['EventReportingService'] = _EVENTREPORTINGSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/jwt_authn/v4alpha/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v4alpha import base_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2
from envoy.config.core.v4alpha import http_uri_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_http__uri__pb2
from envoy.config.route.v4alpha import route_components_pb2 as envoy_dot_config_dot_route_dot_v4alpha_dot_route__components__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/http/jwt_authn/v4alpha/config.proto',
  package='envoy.extensions.filters.http.jwt_authn.v4alpha',
  syntax='proto3',
  serialized_options=b'\n=io.envoyproxy.envoy.extensions.filters.http.jwt_authn.v4alphaB\013ConfigProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n<envoy/extensions/filters/http/jwt_authn/v4alpha/config.proto\x12/envoy.extensions.filters.http.jwt_authn.v4alpha\x1a$envoy/config/core/v4alpha/base.proto\x1a(envoy/config/core/v4alpha/http_uri.proto\x1a\x31\x65nvoy/config/route/v4alpha/route_components.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xfc\x03\n\x0bJwtProvider\x12\x0e\n\x06issuer\x18\x01 \x01(\t\x12\x11\n\taudiences\x18\x02 \x03(\t\x12R\n\x0bremote_jwks\x18\x03 \x01(\x0b\x32;.envoy.extensions.filters.http.jwt_authn.v4alpha.RemoteJwksH\x00\x12;\n\nlocal_jwks\x18\x04 \x01(\x0b\x32%.envoy.config.core.v4alpha.DataSourceH\x00\x12\x0f\n\x07\x66orward\x18\x05 \x01(\x08\x12P\n\x0c\x66rom_headers\x18\x06 \x03(\x0b\x32:.envoy.extensions.filters.http.jwt_authn.v4alpha.JwtHeader\x12\x13\n\x0b\x66rom_params\x18\x07 \x03(\t\x12+\n\x16\x66orward_payload_header\x18\x08 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xc8\x01\x00\x12\x1b\n\x13payload_in_metadata\x18\t \x01(\t\x12\x1a\n\x12\x63lock_skew_seconds\x18\n \x01(\r:=\x9a\xc5\x88\x1e\x38\n6envoy.extensions.filters.http.jwt_authn.v3.JwtProviderB\x1c\n\x15jwks_source_specifier\x12\x03\xf8\x42\x01\"\xb3\x01\n\nRemoteJwks\x12\x34\n\x08http_uri\x18\x01 \x01(\x0b\x32\".envoy.config.core.v4alpha.HttpUri\x12\x31\n\x0e\x63\x61\x63he_duration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration:<\x9a\xc5\x88\x1e\x37\n5envoy.extensions.filters.http.jwt_authn.v3.RemoteJwks\"\x88\x01\n\tJwtHeader\x12\x1b\n\x04name\x18\x01 \x01(\tB\r\xfa\x42\nr\x08\x10\x01\xc0\x01\x01\xc8\x01\x00\x12!\n\x0cvalue_prefix\x18\x02 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x02\xc8\x01\x00:;\x9a\xc5\x88\x1e\x36\n4envoy.extensions.filters.http.jwt_authn.v3.JwtHeader\"\x8a\x01\n\x15ProviderWithAudiences\x12\x15\n\rprovider_name\x18\x01 \x01(\t\x12\x11\n\taudiences\x18\x02 \x03(\t:G\x9a\xc5\x88\x1e\x42\n@envoy.extensions.filters.http.jwt_authn.v3.ProviderWithAudiences\"\x91\x04\n\x0eJwtRequirement\x12\x17\n\rprovider_name\x18\x01 \x01(\tH\x00\x12h\n\x16provider_and_audiences\x18\x02 \x01(\x0b\x32\x46.envoy.extensions.filters.http.jwt_authn.v4alpha.ProviderWithAudiencesH\x00\x12]\n\x0crequires_any\x18\x03 \x01(\x0b\x32\x45.envoy.extensions.filters.http.jwt_authn.v4alpha.JwtRequirementOrListH\x00\x12^\n\x0crequires_all\x18\x04 \x01(\x0b\x32\x46.envoy.extensions.filters.http.jwt_authn.v4alpha.JwtRequirementAndListH\x00\x12\x39\n\x17\x61llow_missing_or_failed\x18\x05 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12/\n\rallow_missing\x18\x06 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00:@\x9a\xc5\x88\x1e;\n9envoy.extensions.filters.http.jwt_authn.v3.JwtRequirementB\x0f\n\rrequires_type\"\xbf\x01\n\x14JwtRequirementOrList\x12_\n\x0crequirements\x18\x01 \x03(\x0b\x32?.envoy.extensions.filters.http.jwt_authn.v4alpha.JwtRequirementB\x08\xfa\x42\x05\x92\x01\x02\x08\x02:F\x9a\xc5\x88\x1e\x41\n?envoy.extensions.filters.http.jwt_authn.v3.JwtRequirementOrList\"\xc1\x01\n\x15JwtRequirementAndList\x12_\n\x0crequirements\x18\x01 \x03(\x0b\x32?.envoy.extensions.filters.http.jwt_authn.v4alpha.JwtRequirementB\x08\xfa\x42\x05\x92\x01\x02\x08\x02:G\x9a\xc5\x88\x1e\x42\n@envoy.extensions.filters.http.jwt_authn.v3.JwtRequirementAndList\"\xa3\x02\n\x0fRequirementRule\x12?\n\x05match\x18\x01 \x01(\x0b\x32&.envoy.config.route.v4alpha.RouteMatchB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12S\n\x08requires\x18\x02 \x01(\x0b\x32?.envoy.extensions.filters.http.jwt_authn.v4alpha.JwtRequirementH\x00\x12#\n\x10requirement_name\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00:A\x9a\xc5\x88\x1e<\n:envoy.extensions.filters.http.jwt_authn.v3.RequirementRuleB\x12\n\x10requirement_type\"\xbf\x02\n\x0f\x46ilterStateRule\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12`\n\x08requires\x18\x03 \x03(\x0b\x32N.envoy.extensions.filters.http.jwt_authn.v4alpha.FilterStateRule.RequiresEntry\x1ap\n\rRequiresEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12N\n\x05value\x18\x02 \x01(\x0b\x32?.envoy.extensions.filters.http.jwt_authn.v4alpha.JwtRequirement:\x02\x38\x01:A\x9a\xc5\x88\x1e<\n:envoy.extensions.filters.http.jwt_authn.v3.FilterStateRule\"\xe5\x05\n\x11JwtAuthentication\x12\x64\n\tproviders\x18\x01 \x03(\x0b\x32Q.envoy.extensions.filters.http.jwt_authn.v4alpha.JwtAuthentication.ProvidersEntry\x12O\n\x05rules\x18\x02 \x03(\x0b\x32@.envoy.extensions.filters.http.jwt_authn.v4alpha.RequirementRule\x12\\\n\x12\x66ilter_state_rules\x18\x03 \x01(\x0b\x32@.envoy.extensions.filters.http.jwt_authn.v4alpha.FilterStateRule\x12\x1d\n\x15\x62ypass_cors_preflight\x18\x04 \x01(\x08\x12o\n\x0frequirement_map\x18\x05 \x03(\x0b\x32V.envoy.extensions.filters.http.jwt_authn.v4alpha.JwtAuthentication.RequirementMapEntry\x1an\n\x0eProvidersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12K\n\x05value\x18\x02 \x01(\x0b\x32<.envoy.extensions.filters.http.jwt_authn.v4alpha.JwtProvider:\x02\x38\x01\x1av\n\x13RequirementMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12N\n\x05value\x18\x02 \x01(\x0b\x32?.envoy.extensions.filters.http.jwt_authn.v4alpha.JwtRequirement:\x02\x38\x01:C\x9a\xc5\x88\x1e>\n<envoy.extensions.filters.http.jwt_authn.v3.JwtAuthentication\"\xb2\x01\n\x0ePerRouteConfig\x12\x1b\n\x08\x64isabled\x18\x01 \x01(\x08\x42\x07\xfa\x42\x04j\x02\x08\x01H\x00\x12#\n\x10requirement_name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00:@\x9a\xc5\x88\x1e;\n9envoy.extensions.filters.http.jwt_authn.v3.PerRouteConfigB\x1c\n\x15requirement_specifier\x12\x03\xf8\x42\x01\x42V\n=io.envoyproxy.envoy.extensions.filters.http.jwt_authn.v4alphaB\x0b\x43onfigProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v4alpha_dot_http__uri__pb2.DESCRIPTOR,envoy_dot_config_dot_route_dot_v4alpha_dot_route__components__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_JWTPROVIDER = _descriptor.Descriptor(
  name='JwtProvider',
  full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtProvider',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='issuer', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtProvider.issuer', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audiences', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtProvider.audiences', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remote_jwks', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtProvider.remote_jwks', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_jwks', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtProvider.local_jwks', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='forward', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtProvider.forward', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from_headers', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtProvider.from_headers', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from_params', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtProvider.from_params', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='forward_payload_header', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtProvider.forward_payload_header', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\010r\006\300\001\001\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload_in_metadata', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtProvider.payload_in_metadata', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock_skew_seconds', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtProvider.clock_skew_seconds', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0368\n6envoy.extensions.filters.http.jwt_authn.v3.JwtProvider',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='jwks_source_specifier', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtProvider.jwks_source_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=397,
  serialized_end=905,
)


_REMOTEJWKS = _descriptor.Descriptor(
  name='RemoteJwks',
  full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.RemoteJwks',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_uri', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.RemoteJwks.http_uri', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cache_duration', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.RemoteJwks.cache_duration', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0367\n5envoy.extensions.filters.http.jwt_authn.v3.RemoteJwks',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=908,
  serialized_end=1087,
)


_JWTHEADER = _descriptor.Descriptor(
  name='JwtHeader',
  full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtHeader.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\nr\010\020\001\300\001\001\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value_prefix', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtHeader.value_prefix', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\010r\006\300\001\002\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0366\n4envoy.extensions.filters.http.jwt_authn.v3.JwtHeader',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1090,
  serialized_end=1226,
)


_PROVIDERWITHAUDIENCES = _descriptor.Descriptor(
  name='ProviderWithAudiences',
  full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.ProviderWithAudiences',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='provider_name', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.ProviderWithAudiences.provider_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audiences', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.ProviderWithAudiences.audiences', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036B\n@envoy.extensions.filters.http.jwt_authn.v3.ProviderWithAudiences',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1229,
  serialized_end=1367,
)


_JWTREQUIREMENT = _descriptor.Descriptor(
  name='JwtRequirement',
  full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtRequirement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='provider_name', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtRequirement.provider_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='provider_and_audiences', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtRequirement.provider_and_audiences', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requires_any', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtRequirement.requires_any', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requires_all', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtRequirement.requires_all', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_missing_or_failed', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtRequirement.allow_missing_or_failed', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_missing', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtRequirement.allow_missing', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036;\n9envoy.extensions.filters.http.jwt_authn.v3.JwtRequirement',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='requires_type', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtRequirement.requires_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1370,
  serialized_end=1899,
)


_JWTREQUIREMENTORLIST = _descriptor.Descriptor(
  name='JwtRequirementOrList',
  full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtRequirementOrList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='requirements', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtRequirementOrList.requirements', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036A\n?envoy.extensions.filters.http.jwt_authn.v3.JwtRequirementOrList',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1902,
  serialized_end=2093,
)


_JWTREQUIREMENTANDLIST = _descriptor.Descriptor(
  name='JwtRequirementAndList',
  full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtRequirementAndList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='requirements', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtRequirementAndList.requirements', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036B\n@envoy.extensions.filters.http.jwt_authn.v3.JwtRequirementAndList',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2096,
  serialized_end=2289,
)


_REQUIREMENTRULE = _descriptor.Descriptor(
  name='RequirementRule',
  full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.RequirementRule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='match', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.RequirementRule.match', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requires', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.RequirementRule.requires', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requirement_name', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.RequirementRule.requirement_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036<\n:envoy.extensions.filters.http.jwt_authn.v3.RequirementRule',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='requirement_type', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.RequirementRule.requirement_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2292,
  serialized_end=2583,
)


_FILTERSTATERULE_REQUIRESENTRY = _descriptor.Descriptor(
  name='RequiresEntry',
  full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.FilterStateRule.RequiresEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.FilterStateRule.RequiresEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.FilterStateRule.RequiresEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2726,
  serialized_end=2838,
)

_FILTERSTATERULE = _descriptor.Descriptor(
  name='FilterStateRule',
  full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.FilterStateRule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.FilterStateRule.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requires', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.FilterStateRule.requires', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FILTERSTATERULE_REQUIRESENTRY, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036<\n:envoy.extensions.filters.http.jwt_authn.v3.FilterStateRule',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2586,
  serialized_end=2905,
)


_JWTAUTHENTICATION_PROVIDERSENTRY = _descriptor.Descriptor(
  name='ProvidersEntry',
  full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtAuthentication.ProvidersEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtAuthentication.ProvidersEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtAuthentication.ProvidersEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3350,
  serialized_end=3460,
)

_JWTAUTHENTICATION_REQUIREMENTMAPENTRY = _descriptor.Descriptor(
  name='RequirementMapEntry',
  full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtAuthentication.RequirementMapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtAuthentication.RequirementMapEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtAuthentication.RequirementMapEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3462,
  serialized_end=3580,
)

_JWTAUTHENTICATION = _descriptor.Descriptor(
  name='JwtAuthentication',
  full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtAuthentication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='providers', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtAuthentication.providers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rules', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtAuthentication.rules', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter_state_rules', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtAuthentication.filter_state_rules', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bypass_cors_preflight', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtAuthentication.bypass_cors_preflight', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requirement_map', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtAuthentication.requirement_map', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_JWTAUTHENTICATION_PROVIDERSENTRY, _JWTAUTHENTICATION_REQUIREMENTMAPENTRY, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036>\n<envoy.extensions.filters.http.jwt_authn.v3.JwtAuthentication',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2908,
  serialized_end=3649,
)


_PERROUTECONFIG = _descriptor.Descriptor(
  name='PerRouteConfig',
  full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.PerRouteConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='disabled', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.PerRouteConfig.disabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004j\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requirement_name', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.PerRouteConfig.requirement_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036;\n9envoy.extensions.filters.http.jwt_authn.v3.PerRouteConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='requirement_specifier', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.PerRouteConfig.requirement_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=3652,
  serialized_end=3830,
)

_JWTPROVIDER.fields_by_name['remote_jwks'].message_type = _REMOTEJWKS
_JWTPROVIDER.fields_by_name['local_jwks'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._DATASOURCE
_JWTPROVIDER.fields_by_name['from_headers'].message_type = _JWTHEADER
_JWTPROVIDER.oneofs_by_name['jwks_source_specifier'].fields.append(
  _JWTPROVIDER.fields_by_name['remote_jwks'])
_JWTPROVIDER.fields_by_name['remote_jwks'].containing_oneof = _JWTPROVIDER.oneofs_by_name['jwks_source_specifier']
_JWTPROVIDER.oneofs_by_name['jwks_source_specifier'].fields.append(
  _JWTPROVIDER.fields_by_name['local_jwks'])
_JWTPROVIDER.fields_by_name['local_jwks'].containing_oneof = _JWTPROVIDER.oneofs_by_name['jwks_source_specifier']
_REMOTEJWKS.fields_by_name['http_uri'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_http__uri__pb2._HTTPURI
_REMOTEJWKS.fields_by_name['cache_duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_JWTREQUIREMENT.fields_by_name['provider_and_audiences'].message_type = _PROVIDERWITHAUDIENCES
_JWTREQUIREMENT.fields_by_name['requires_any'].message_type = _JWTREQUIREMENTORLIST
_JWTREQUIREMENT.fields_by_name['requires_all'].message_type = _JWTREQUIREMENTANDLIST
_JWTREQUIREMENT.fields_by_name['allow_missing_or_failed'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_JWTREQUIREMENT.fields_by_name['allow_missing'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_JWTREQUIREMENT.oneofs_by_name['requires_type'].fields.append(
  _JWTREQUIREMENT.fields_by_name['provider_name'])
_JWTREQUIREMENT.fields_by_name['provider_name'].containing_oneof = _JWTREQUIREMENT.oneofs_by_name['requires_type']
_JWTREQUIREMENT.oneofs_by_name['requires_type'].fields.append(
  _JWTREQUIREMENT.fields_by_name['provider_and_audiences'])
_JWTREQUIREMENT.fields_by_name['provider_and_audiences'].containing_oneof = _JWTREQUIREMENT.oneofs_by_name['requires_type']
_JWTREQUIREMENT.oneofs_by_name['requires_type'].fields.append(
  _JWTREQUIREMENT.fields_by_name['requires_any'])
_JWTREQUIREMENT.fields_by_name['requires_any'].containing_oneof = _JWTREQUIREMENT.oneofs_by_name['requires_type']
_JWTREQUIREMENT.oneofs_by_name['requires_type'].fields.append(
  _JWTREQUIREMENT.fields_by_name['requires_all'])
_JWTREQUIREMENT.fields_by_name['requires_all'].containing_oneof = _JWTREQUIREMENT.oneofs_by_name['requires_type']
_JWTREQUIREMENT.oneofs_by_name['requires_type'].fields.append(
  _JWTREQUIREMENT.fields_by_name['allow_missing_or_failed'])
_JWTREQUIREMENT.fields_by_name['allow_missing_or_failed'].containing_oneof = _JWTREQUIREMENT.oneofs_by_name['requires_type']
_JWTREQUIREMENT.oneofs_by_name['requires_type'].fields.append(
  _JWTREQUIREMENT.fields_by_name['allow_missing'])
_JWTREQUIREMENT.fields_by_name['allow_missing'].containing_oneof = _JWTREQUIREMENT.oneofs_by_name['requires_type']
_JWTREQUIREMENTORLIST.fields_by_name['requirements'].message_type = _JWTREQUIREMENT
_JWTREQUIREMENTANDLIST.fields_by_name['requirements'].message_type = _JWTREQUIREMENT
_REQUIREMENTRULE.fields_by_name['match'].message_type = envoy_dot_config_dot_route_dot_v4alpha_dot_route__components__pb2._ROUTEMATCH
_REQUIREMENTRULE.fields_by_name['requires'].message_type = _JWTREQUIREMENT
_REQUIREMENTRULE.oneofs_by_name['requirement_type'].fields.append(
  _REQUIREMENTRULE.fields_by_name['requires'])
_REQUIREMENTRULE.fields_by_name['requires'].containing_oneof = _REQUIREMENTRULE.oneofs_by_name['requirement_type']
_REQUIREMENTRULE.oneofs_by_name['requirement_type'].fields.append(
  _REQUIREMENTRULE.fields_by_name['requirement_name'])
_REQUIREMENTRULE.fields_by_name['requirement_name'].containing_oneof = _REQUIREMENTRULE.oneofs_by_name['requirement_type']
_FILTERSTATERULE_REQUIRESENTRY.fields_by_name['value'].message_type = _JWTREQUIREMENT
_FILTERSTATERULE_REQUIRESENTRY.containing_type = _FILTERSTATERULE
_FILTERSTATERULE.fields_by_name['requires'].message_type = _FILTERSTATERULE_REQUIRESENTRY
_JWTAUTHENTICATION_PROVIDERSENTRY.fields_by_name['value'].message_type = _JWTPROVIDER
_JWTAUTHENTICATION_PROVIDERSENTRY.containing_type = _JWTAUTHENTICATION
_JWTAUTHENTICATION_REQUIREMENTMAPENTRY.fields_by_name['value'].message_type = _JWTREQUIREMENT
_JWTAUTHENTICATION_REQUIREMENTMAPENTRY.containing_type = _JWTAUTHENTICATION
_JWTAUTHENTICATION.fields_by_name['providers'].message_type = _JWTAUTHENTICATION_PROVIDERSENTRY
_JWTAUTHENTICATION.fields_by_name['rules'].message_type = _REQUIREMENTRULE
_JWTAUTHENTICATION.fields_by_name['filter_state_rules'].message_type = _FILTERSTATERULE
_JWTAUTHENTICATION.fields_by_name['requirement_map'].message_type = _JWTAUTHENTICATION_REQUIREMENTMAPENTRY
_PERROUTECONFIG.oneofs_by_name['requirement_specifier'].fields.append(
  _PERROUTECONFIG.fields_by_name['disabled'])
_PERROUTECONFIG.fields_by_name['disabled'].containing_oneof = _PERROUTECONFIG.oneofs_by_name['requirement_specifier']
_PERROUTECONFIG.oneofs_by_name['requirement_specifier'].fields.append(
  _PERROUTECONFIG.fields_by_name['requirement_name'])
_PERROUTECONFIG.fields_by_name['requirement_name'].containing_oneof = _PERROUTECONFIG.oneofs_by_name['requirement_specifier']
DESCRIPTOR.message_types_by_name['JwtProvider'] = _JWTPROVIDER
DESCRIPTOR.message_types_by_name['RemoteJwks'] = _REMOTEJWKS
DESCRIPTOR.message_types_by_name['JwtHeader'] = _JWTHEADER
DESCRIPTOR.message_types_by_name['ProviderWithAudiences'] = _PROVIDERWITHAUDIENCES
DESCRIPTOR.message_types_by_name['JwtRequirement'] = _JWTREQUIREMENT
DESCRIPTOR.message_types_by_name['JwtRequirementOrList'] = _JWTREQUIREMENTORLIST
DESCRIPTOR.message_types_by_name['JwtRequirementAndList'] = _JWTREQUIREMENTANDLIST
DESCRIPTOR.message_types_by_name['RequirementRule'] = _REQUIREMENTRULE
DESCRIPTOR.message_types_by_name['FilterStateRule'] = _FILTERSTATERULE
DESCRIPTOR.message_types_by_name['JwtAuthentication'] = _JWTAUTHENTICATION
DESCRIPTOR.message_types_by_name['PerRouteConfig'] = _PERROUTECONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

JwtProvider = _reflection.GeneratedProtocolMessageType('JwtProvider', (_message.Message,), {
  'DESCRIPTOR' : _JWTPROVIDER,
  '__module__' : 'envoy.extensions.filters.http.jwt_authn.v4alpha.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.jwt_authn.v4alpha.JwtProvider)
  })
_sym_db.RegisterMessage(JwtProvider)

RemoteJwks = _reflection.GeneratedProtocolMessageType('RemoteJwks', (_message.Message,), {
  'DESCRIPTOR' : _REMOTEJWKS,
  '__module__' : 'envoy.extensions.filters.http.jwt_authn.v4alpha.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.jwt_authn.v4alpha.RemoteJwks)
  })
_sym_db.RegisterMessage(RemoteJwks)

JwtHeader = _reflection.GeneratedProtocolMessageType('JwtHeader', (_message.Message,), {
  'DESCRIPTOR' : _JWTHEADER,
  '__module__' : 'envoy.extensions.filters.http.jwt_authn.v4alpha.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.jwt_authn.v4alpha.JwtHeader)
  })
_sym_db.RegisterMessage(JwtHeader)

ProviderWithAudiences = _reflection.GeneratedProtocolMessageType('ProviderWithAudiences', (_message.Message,), {
  'DESCRIPTOR' : _PROVIDERWITHAUDIENCES,
  '__module__' : 'envoy.extensions.filters.http.jwt_authn.v4alpha.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.jwt_authn.v4alpha.ProviderWithAudiences)
  })
_sym_db.RegisterMessage(ProviderWithAudiences)

JwtRequirement = _reflection.GeneratedProtocolMessageType('JwtRequirement', (_message.Message,), {
  'DESCRIPTOR' : _JWTREQUIREMENT,
  '__module__' : 'envoy.extensions.filters.http.jwt_authn.v4alpha.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.jwt_authn.v4alpha.JwtRequirement)
  })
_sym_db.RegisterMessage(JwtRequirement)

JwtRequirementOrList = _reflection.GeneratedProtocolMessageType('JwtRequirementOrList', (_message.Message,), {
  'DESCRIPTOR' : _JWTREQUIREMENTORLIST,
  '__module__' : 'envoy.extensions.filters.http.jwt_authn.v4alpha.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.jwt_authn.v4alpha.JwtRequirementOrList)
  })
_sym_db.RegisterMessage(JwtRequirementOrList)

JwtRequirementAndList = _reflection.GeneratedProtocolMessageType('JwtRequirementAndList', (_message.Message,), {
  'DESCRIPTOR' : _JWTREQUIREMENTANDLIST,
  '__module__' : 'envoy.extensions.filters.http.jwt_authn.v4alpha.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.jwt_authn.v4alpha.JwtRequirementAndList)
  })
_sym_db.RegisterMessage(JwtRequirementAndList)

RequirementRule = _reflection.GeneratedProtocolMessageType('RequirementRule', (_message.Message,), {
  'DESCRIPTOR' : _REQUIREMENTRULE,
  '__module__' : 'envoy.extensions.filters.http.jwt_authn.v4alpha.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.jwt_authn.v4alpha.RequirementRule)
  })
_sym_db.RegisterMessage(RequirementRule)

FilterStateRule = _reflection.GeneratedProtocolMessageType('FilterStateRule', (_message.Message,), {

  'RequiresEntry' : _reflection.GeneratedProtocolMessageType('RequiresEntry', (_message.Message,), {
    'DESCRIPTOR' : _FILTERSTATERULE_REQUIRESENTRY,
    '__module__' : 'envoy.extensions.filters.http.jwt_authn.v4alpha.config_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.jwt_authn.v4alpha.FilterStateRule.RequiresEntry)
    })
  ,
  'DESCRIPTOR' : _FILTERSTATERULE,
  '__module__' : 'envoy.extensions.filters.http.jwt_authn.v4alpha.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.jwt_authn.v4alpha.FilterStateRule)
  })
_sym_db.RegisterMessage(FilterStateRule)
_sym_db.RegisterMessage(FilterStateRule.RequiresEntry)

JwtAuthentication = _reflection.GeneratedProtocolMessageType('JwtAuthentication', (_message.Message,), {

  'ProvidersEntry' : _reflection.GeneratedProtocolMessageType('ProvidersEntry', (_message.Message,), {
    'DESCRIPTOR' : _JWTAUTHENTICATION_PROVIDERSENTRY,
    '__module__' : 'envoy.extensions.filters.http.jwt_authn.v4alpha.config_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.jwt_authn.v4alpha.JwtAuthentication.ProvidersEntry)
    })
  ,

  'RequirementMapEntry' : _reflection.GeneratedProtocolMessageType('RequirementMapEntry', (_message.Message,), {
    'DESCRIPTOR' : _JWTAUTHENTICATION_REQUIREMENTMAPENTRY,
    '__module__' : 'envoy.extensions.filters.http.jwt_authn.v4alpha.config_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.jwt_authn.v4alpha.JwtAuthentication.RequirementMapEntry)
    })
  ,
  'DESCRIPTOR' : _JWTAUTHENTICATION,
  '__module__' : 'envoy.extensions.filters.http.jwt_authn.v4alpha.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.jwt_authn.v4alpha.JwtAuthentication)
  })
_sym_db.RegisterMessage(JwtAuthentication)
_sym_db.RegisterMessage(JwtAuthentication.ProvidersEntry)
_sym_db.RegisterMessage(JwtAuthentication.RequirementMapEntry)

PerRouteConfig = _reflection.GeneratedProtocolMessageType('PerRouteConfig', (_message.Message,), {
  'DESCRIPTOR' : _PERROUTECONFIG,
  '__module__' : 'envoy.extensions.filters.http.jwt_authn.v4alpha.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.jwt_authn.v4alpha.PerRouteConfig)
  })
_sym_db.RegisterMessage(PerRouteConfig)


DESCRIPTOR._options = None
_JWTPROVIDER.oneofs_by_name['jwks_source_specifier']._options = None
_JWTPROVIDER.fields_by_name['forward_payload_header']._options = None
_JWTPROVIDER._options = None
_REMOTEJWKS._options = None
_JWTHEADER.fields_by_name['name']._options = None
_JWTHEADER.fields_by_name['value_prefix']._options = None
_JWTHEADER._options = None
_PROVIDERWITHAUDIENCES._options = None
_JWTREQUIREMENT._options = None
_JWTREQUIREMENTORLIST.fields_by_name['requirements']._options = None
_JWTREQUIREMENTORLIST._options = None
_JWTREQUIREMENTANDLIST.fields_by_name['requirements']._options = None
_JWTREQUIREMENTANDLIST._options = None
_REQUIREMENTRULE.fields_by_name['match']._options = None
_REQUIREMENTRULE.fields_by_name['requirement_name']._options = None
_REQUIREMENTRULE._options = None
_FILTERSTATERULE_REQUIRESENTRY._options = None
_FILTERSTATERULE.fields_by_name['name']._options = None
_FILTERSTATERULE._options = None
_JWTAUTHENTICATION_PROVIDERSENTRY._options = None
_JWTAUTHENTICATION_REQUIREMENTMAPENTRY._options = None
_JWTAUTHENTICATION._options = None
_PERROUTECONFIG.oneofs_by_name['requirement_specifier']._options = None
_PERROUTECONFIG.fields_by_name['disabled']._options = None
_PERROUTECONFIG.fields_by_name['requirement_name']._options = None
_PERROUTECONFIG._options = None
# @@protoc_insertion_point(module_scope)
